GrainyHead Manual
=================

GrainyHead is a set of command-line tools to interact with `GitHub`_
repositories.

.. _GitHub: https://github.com/

GrainyHead is free software, published under the GNU General Public License.
It is written in Python and should work with Python 3.9+.


.. toctree::
   :maxdepth: 2

   install
   quickstart
   old-issues
   metrics
   configuration
